package com.demo.insurance.customj;

import com.demo.insurance.to.Address;
import com.demo.insurance.to.LetterRequest;
import com.demo.insurance.to.PersonalInfo;
import com.demo.soa.esb.util.customj.AbstractXQService;
import com.demo.soa.esb.util.exception.XMLException;
import com.demo.soa.esb.xml.XMLParserFactory;
import com.sonicsw.xq.XQEnvelope;
import com.sonicsw.xq.XQMessage;
import com.sonicsw.xq.XQMessageException;
import com.sonicsw.xq.XQPart;
import com.sonicsw.xq.XQServiceContext;
import com.sonicsw.xq.XQServiceException;

/**
 * This Custom Java Service simulates sending of a letter to a customer. It was
 * written specifically for this demo application to provide some sample
 * services for the rules engine to call and demonstrate its long running
 * transaction orchestration capabilities.
 * 
 * @author Leon Rubin
 */
public class LetterService extends AbstractXQService {
	/**
	 * Constructor for a LetterService.
	 */
	public LetterService() {
		super("LetterService");
	}

	/**
	 * Retrieves the letter request XML from the part content, parses it obtain
	 * the required information, and simulates sending of a letter to the
	 * customer by printing the letter type, recipient name, recipient address,
	 * and a character rendering of an envelope.
	 * 
	 * @param ctx	service context
	 * @param env	the envelope being processed
	 * @param msg	the message being processed
	 * @param part	the part being processed
	 * @param partIndex	the index of the part being processed
	 */
	protected void processPart(XQServiceContext ctx, XQEnvelope env,
			XQMessage msg, XQPart part, int partIndex)
			throws XQServiceException, XQMessageException {
		if (partIndex == 0) {
			String xml = part.getContent().toString();
			try {
				LetterRequest letterRequest = (LetterRequest) XMLParserFactory
						.getXMLParser().parse(xml);

				PersonalInfo recipientInfo = letterRequest.getRecipientInfo();
				Address address = recipientInfo.getAddress();

				m_xqLog.logInformation("Sending a letter of type "
						+ letterRequest.getLetterTypeName());
				m_xqLog.logInformation("To: " + recipientInfo.getFirstName()
						+ " " + recipientInfo.getLastName());
				m_xqLog.logInformation("Address: " + address.getLine1());
				m_xqLog.logInformation("\t\t" + address.getLine2());
				m_xqLog.logInformation("\t\t" + address.getCity());
				m_xqLog.logInformation("\t\t" + address.getState());
				m_xqLog.logInformation("\t\t" + address.getZip() + "\n");
				m_xqLog.logInformation("**************************************");
				m_xqLog.logInformation("* *                                * *");
				m_xqLog.logInformation("*   *                            *   *");
				m_xqLog.logInformation("*     *                        *     *");
				m_xqLog.logInformation("*       *                    *       *");
				m_xqLog.logInformation("*         *                *         *");
				m_xqLog.logInformation("*         * *            * *         *");
				m_xqLog.logInformation("*       *     *        *     *       *");
				m_xqLog.logInformation("*     *          *   *         *     *");
				m_xqLog.logInformation("*   *              **            *   *");
				m_xqLog.logInformation("* *                                * *");
				m_xqLog.logInformation("**************************************");
			} catch (XMLException e) {
				e.printStackTrace();
				throw new XQServiceException(
						"Failed to parse letter request XML", e);
			}
		}
	}
}