package com.demo.insurance.customj;

import com.demo.insurance.to.MedicalReportRequest;
import com.demo.insurance.to.PersonalInfo;
import com.demo.soa.esb.util.customj.AbstractXQService;
import com.demo.soa.esb.util.exception.XMLException;
import com.demo.soa.esb.xml.XMLParserFactory;
import com.sonicsw.xq.XQEnvelope;
import com.sonicsw.xq.XQMessage;
import com.sonicsw.xq.XQMessageException;
import com.sonicsw.xq.XQPart;
import com.sonicsw.xq.XQServiceContext;
import com.sonicsw.xq.XQServiceException;

/**
 * This Custom Java Service simulates an asynchronous request to a medical
 * information agency that are common in insurance industry and are similar to
 * credit bureaus of the financial industry. Some medical services expose
 * synchronous Web Services that provide an immediate response while others
 * require customers to participate in medical tests and questionnaires and send
 * the results few days or even weeks later. Since this application simulates a
 * long running transaction, this service simulates the second type of medical
 * report. This service doesn't really call any external services, just writes
 * some information to the log pretending that the request has been sent. The
 * user can then simulate the asynchronous reply from the medical information
 * agency by posting an XML representation of a Medical Report for that
 * applicant using the JMS test client.
 * 
 * @author Leon Rubin
 */
public class MedicalReportService extends AbstractXQService {
	/**
	 * Constructor for a MedicalReportService
	 */
	public MedicalReportService() {
		super("MedicalReportService");
	}

	/**
	 * Retrieves the medical report request XML from the part content, parses it
	 * obtain the required information, and simulates sending of a request to
	 * the medical information agency by printing the personal information of
	 * the applicant and a character rendering of a medical symbol.
	 * 
	 * @param ctx	service context
	 * @param env	the envelope being processed
	 * @param msg	the message being processed
	 * @param part	the part being processed
	 * @param partIndex	the index of the part being processed
	 */
	protected void processPart(XQServiceContext ctx, XQEnvelope env,
			XQMessage msg, XQPart part, int partIndex)
			throws XQServiceException, XQMessageException {
		if (partIndex == 0) {
			String xml = part.getContent().toString();
			try {
				MedicalReportRequest medicalReportRequest = (MedicalReportRequest) XMLParserFactory
						.getXMLParser().parse(xml);

				PersonalInfo personalInfo = medicalReportRequest
						.getPersonalInfo();

				m_xqLog.logInformation("Requesting Medical Report for: "
						+ personalInfo.getFirstName() + " "
						+ personalInfo.getLastName());
				m_xqLog.logInformation("        **********");
				m_xqLog.logInformation("        *        *");
				m_xqLog.logInformation("        *        *");
				m_xqLog.logInformation("        *        *");
				m_xqLog.logInformation("*********        **********");
				m_xqLog.logInformation("*                         *");
				m_xqLog.logInformation("*                         *");
				m_xqLog.logInformation("*                         *");
				m_xqLog.logInformation("*********        **********");
				m_xqLog.logInformation("        *        *");
				m_xqLog.logInformation("        *        *");
				m_xqLog.logInformation("        *        *");
				m_xqLog.logInformation("        **********");
			} catch (XMLException e) {
				e.printStackTrace();
				throw new XQServiceException(
						"Failed to parse medical request XML", e);
			}
		}
	}
}