package com.demo.insurance.customj;

import com.demo.insurance.to.PersonalInfo;
import com.demo.insurance.to.PolicyIssueRequest;
import com.demo.soa.esb.util.customj.AbstractXQService;
import com.demo.soa.esb.util.exception.XMLException;
import com.demo.soa.esb.xml.XMLParserFactory;
import com.sonicsw.xq.XQEnvelope;
import com.sonicsw.xq.XQMessage;
import com.sonicsw.xq.XQMessageException;
import com.sonicsw.xq.XQPart;
import com.sonicsw.xq.XQServiceContext;
import com.sonicsw.xq.XQServiceException;

/**
 * This Custom Java Service simulates a call to a policy issue system. It was
 * written specifically for this demo application to provide some sample
 * services for the rules engine to call and demonstrate its long running
 * transaction orchestration capabilities.
 * 
 * @author Leon Rubin
 */
public class PolicyIssueService extends AbstractXQService   { 
    /**
     * Constructor for a PolicyIssueService
     */
	public PolicyIssueService () {	
		super("PolicyIssueService");
	}
	
	/**
	 * Retrieves the policy issue request XML from the part content, parses it obtain the 
	 * required information, and simulates the act of issuing a policy by printing the  
	 * personal information of the applicant and a character rendering of a policy document.
	 * 
	 * @param ctx	service context
	 * @param env	the envelope being processed
	 * @param msg	the message being processed
	 * @param part	the part being processed
	 * @param partIndex	the index of the part being processed
	 */
	protected void processPart(XQServiceContext ctx, XQEnvelope env, XQMessage msg,
			XQPart part, int partIndex) throws XQServiceException,
			XQMessageException {
		if (partIndex == 0) {
			String xml = part.getContent().toString();
			try {
				PolicyIssueRequest policyIssueRequest = (PolicyIssueRequest) XMLParserFactory
						.getXMLParser().parse(xml);

				PersonalInfo personalInfo = policyIssueRequest
						.getInsuredInfo();

				m_xqLog.logInformation("Issuing a Policy for: "
						+ personalInfo.getFirstName() + " "
						+ personalInfo.getLastName());
			
				m_xqLog.logInformation("**************************");
				m_xqLog.logInformation("*                        * *");
				m_xqLog.logInformation("*                        *   *");
				m_xqLog.logInformation("*           POLICY       *******");
				m_xqLog.logInformation("*   _______________________    *");
				m_xqLog.logInformation("*                              *");
				m_xqLog.logInformation("*   _______________________    *");
				m_xqLog.logInformation("*                              *");
				m_xqLog.logInformation("*   _______________________    *");
				m_xqLog.logInformation("*                              *");
				m_xqLog.logInformation("*   _______________________    *");
				m_xqLog.logInformation("*                              *");
				m_xqLog.logInformation("*   _______________________    *");
				m_xqLog.logInformation("*                              *");
				m_xqLog.logInformation("*   _______________________    *");
				m_xqLog.logInformation("*                              *");
				m_xqLog.logInformation("*   _______________________    *");
				m_xqLog.logInformation("*                              *");
				m_xqLog.logInformation("********************************");
			} catch (XMLException e) {
				e.printStackTrace();
				throw new XQServiceException(
						"Failed to parse policy issue request XML", e);
			}
		}
	}
}