package com.demo.insurance.to;

import com.demo.soa.esb.util.to.ModelBean;

/**
 * This class represents a mailing address.
 * 
 * @author Leon Rubin
 */
public class Address extends ModelBean {
	private String line1;
	private String line2;
	private String city;
	private String state;
	private String zip;

	/**
	 * Gets the first address line.
	 * 
	 * @return String containing the first address line
	 */
	public String getLine1() {
		return line1;
	}

	/**
	 * Sets the first address line.
	 * 
	 * @param the
	 *            first address line
	 */
	public void setLine1(String line1) {
		this.line1 = line1;
	}

	/**
	 * Gets the second address line.
	 * 
	 * @return String containing the second address line
	 */
	public String getLine2() {
		return line2;
	}

	/**
	 * Sets the second address line.
	 * 
	 * @param the
	 *            second address line
	 */
	public void setLine2(String line2) {
		this.line2 = line2;
	}

	/**
	 * Gets the city name.
	 * 
	 * @return String containing the city name
	 */
	public String getCity() {
		return city;
	}

	/**
	 * Sets the city name.
	 * 
	 * @param city
	 *            name
	 */
	public void setCity(String city) {
		this.city = city;
	}

	/**
	 * Gets the state abbreviation.
	 * 
	 * @return String containing the state abbreviation
	 */
	public String getState() {
		return state;
	}

	/**
	 * Sets the state abbreviation.
	 * 
	 * @param state
	 *            abbreviation
	 */
	public void setState(String state) {
		this.state = state;
	}

	/**
	 * Gets the zip code.
	 * 
	 * @return String containing the zip code
	 */
	public String getZip() {
		return zip;
	}

	/**
	 * Sets the zip code.
	 * 
	 * @param zip
	 *            code
	 */
	public void setZip(String zip) {
		this.zip = zip;
	}

	/**
	 * Test the equality of this object and another object by comparing all
	 * individual address fields rather than the default behaviour of comparing
	 * references.
	 * 
	 * @return <code>true</code> if the objects are equal and
	 *         <code>false</code> otherwise
	 */
	public boolean equals(Object o) {
		boolean result = false;

		if (o instanceof Address) {
			Address address = (Address) o;

			if (line1.equals(address.line1) && line2.equals(address.line2)
					&& city.equals(address.city) && state.equals(address.state)
					&& zip.equals(address.zip)) {
				result = true;
			}
		}

		return result;
	}

	/**
	 * Creates a hash code for this object by adding the hash codes of
	 * individual fields.
	 * 
	 * @return integer container the hash code for this object
	 */
	public int hashCode() {
		return hashCode(line1) + hashCode(line2) + hashCode(city)
				+ hashCode(state) + hashCode(zip);
	}

	/**
	 * Creates a string representation for this object by printing out the class
	 * name and individual fields to produce a more meaningful output than the
	 * default implementation.
	 * 
	 * @return String representation of this object
	 */
	public String toString() {
		StringBuffer buffer = new StringBuffer();

		buffer.append("\n\t\t" + getClass().getName() + "{");
		buffer.append("\n\t\t\tline1=" + line1);
		buffer.append("\n\t\t\tline2=" + line2);
		buffer.append("\n\t\t\tcity=" + city);
		buffer.append("\n\t\t\tstate=" + state);
		buffer.append("\n\t\t\tzip=" + zip);
		buffer.append("\n\t\t}\n");

		return buffer.toString();
	}
}
