package com.demo.insurance.to;

/**
 * This class defines integer constants that represent all valid application
 * statuses. The status of an application changes as it moves through stages of
 * its lifecycle (NEW, VALIDATED, DECLINED, APPROVED, etc). In the future (when
 * there is no requirement to be backward compatible with JDK 1.4), this class
 * can become and enumeration.
 * 
 * @author Leon Rubin
 */
public class ApplicationStatus {
	/**
	 * The the application is created, its status is set to NEW.
	 */
	public static final int NEW = 1;

	/**
	 * When the application is validated (authorization form is present, etc),
	 * its status changes to VALIDATED.
	 */
	public static final int VALIDATED = 2;

	/**
	 * When the application missing requried information (authorization form is
	 * not attached, etc), its status changes to INCOMPLETE.
	 */
	public static final int INCOMPLETE = 3;

	/**
	 * When a medical report is requested for an applicant, the application is
	 * placed in WAITING_FOR_MEDICAL_REPORT status.
	 */
	public static final int WAITING_FOR_MEDICAL_REPORT = 4;

	/**
	 * When a medical report is received, the application is placed in
	 * MEDICAL_REPORT_RECEIVED status.
	 */
	public static final int MEDICAL_REPORT_RECEIVED = 5;

	/**
	 * When the application is approved (based on a good medical report, etc),
	 * the application is placed in APPROVED status.
	 */
	public static final int APPROVED = 6;

	/**
	 * When the application is declined (based on a bad medical report, etc),
	 * the application is placed in DECLINED status.
	 */
	public static final int DECLINED = 7;

	/**
	 * Gets the application status as a string which is often useful for
	 * debugging and other purposes since the status is stored as integer.
	 * 
	 * @param status
	 *            application status integer code
	 * @return application status name
	 */
	public static String getStatusName(int status) {
		String statusName = "Invalid Status Code";

		if (status == 1) {
			statusName = "NEW";
		} else if (status == 2) {
			statusName = "VALIDATED";
		} else if (status == 3) {
			statusName = "INCOMPLETE";
		} else if (status == 4) {
			statusName = "WAITING_FOR_MEDICAL_REPORT";
		} else if (status == 5) {
			statusName = "MEDICAL_REPORT_RECEIVED";
		} else if (status == 6) {
			statusName = "APPROVED";
		} else if (status == 7) {
			statusName = "DECLINED";
		}

		return statusName;
	}
}
