package com.demo.insurance.to;


/**
 * This class represents an authorization form that should be attached to the
 * application to authorize the insurance company to search for applicant's
 * medical information. This is common in insurance business and may be due to
 * some HIPA regulations.
 * 
 * @author Leon Rubin
 */
public class AuthorizationForm extends ObjectWithReferenceNumber {
	private boolean signed;

	/**
	 * Indicates whether the authorization form was signed. Authorization form
	 * is invalid without a signature.
	 * 
	 * @return <code>true</code> if an authorization form was signed and
	 *         <code>false</code> otherwise
	 */
	public boolean isSigned() {
		return signed;
	}

	/**
	 * Sets the signed indicator.
	 * 
	 * @param signed
	 *            value of the signed indicator
	 */
	public void setSigned(boolean signed) {
		this.signed = signed;
	}

	/**
	 * Test the equality of this object and another object by comparing all
	 * individual address fields rather than the default behaviour of comparing
	 * references.
	 * 
	 * @return <code>true</code> if the objects are equal and
	 *         <code>false</code> otherwise
	 */
	public boolean equals(Object o) {
		boolean result = false;

		if (o instanceof AuthorizationForm) {
			AuthorizationForm authorizationForm = (AuthorizationForm) o;

			if (getReferenceNumber().equals(
					authorizationForm.getReferenceNumber())
					&& signed == authorizationForm.signed) {
				result = true;
			}
		}

		return result;
	}

	/**
	 * Creates a hash code for this object by adding the hash codes of
	 * individual fields.
	 * 
	 * @return integer container the hash code for this object
	 */
	public int hashCode() {
		return hashCode(getReferenceNumber()) + hashCode(signed);
	}

	/**
	 * Creates a string representation for this object by printing out the class
	 * name and individual fields to produce a more meaningful output than the
	 * default implementation.
	 * 
	 * @return String representation of this object
	 */
	public String toString() {
		StringBuffer buffer = new StringBuffer();

		buffer.append("\n" + getClass().getName() + "{");
		buffer.append("\n\treferenceNumber=" + getReferenceNumber());
		buffer.append("\n\tsigned=" + signed);
		buffer.append("\n}\n");

		return buffer.toString();
	}
}
