package com.demo.insurance.to;

import com.demo.soa.esb.util.to.ModelBean;

/**
 * This class represents a request to the letter service and describes the
 * letter that should be sent (letter type, recipient name, recipient address,
 * etc).
 * 
 * @author Leon Rubin
 */
public class LetterRequest extends ModelBean {
	private int letterType;
	private PersonalInfo recipientInfo;

	/**
	 * Gets the letter type. Valid letter type values are defined in the
	 * LetterType class. In the future (when there is no requirement to be
	 * backward compatible with JDK 1.4), the letter type can be represented by
	 * an enumeration.
	 * 
	 * @return letter type
	 */
	public int getLetterType() {
		return letterType;
	}

	/**
	 * Sets the letter type.
	 * 
	 * @param letterType
	 *            integer code representing the letter type. Use constants from
	 *            the LetterType class as parameters to this method
	 */
	public void setLetterType(int letterType) {
		this.letterType = letterType;
	}

	/**
	 * Gets the letter type as a string which is often useful for debugging and
	 * other purposes since the letter type is stored as integer. In the future
	 * (when there is no requirement to be backward compatible with JDK 1.4),
	 * the letter type can be represented by an enumeration and this method may
	 * not be needed
	 * 
	 * @return letter type name
	 */
	public String getLetterTypeName() {
		return LetterType.getLetterTypeName(letterType);
	}

	/**
	 * Gets the personal informaiton of the recipient.
	 * 
	 * @return personal informaiton of the recipient
	 */
	public PersonalInfo getRecipientInfo() {
		return recipientInfo;
	}

	/**
	 * Sets the personal informaiton of the recipient.
	 * 
	 * @param applicantInfo
	 *            personal informaiton of the recipient
	 */
	public void setRecipientInfo(PersonalInfo recipientInfo) {
		this.recipientInfo = recipientInfo;
	}

	/**
	 * Test the equality of this object and another object by comparing all
	 * individual address fields rather than the default behaviour of comparing
	 * references.
	 * 
	 * @return <code>true</code> if the objects are equal and
	 *         <code>false</code> otherwise
	 */
	public boolean equals(Object o) {
		boolean result = false;

		if (o instanceof LetterRequest) {
			LetterRequest letterRequest = (LetterRequest) o;

			if (letterType == letterRequest.letterType
					&& recipientInfo.equals(letterRequest.recipientInfo)) {
				result = true;
			}
		}

		return result;
	}

	/**
	 * Creates a hash code for this object by adding the hash codes of
	 * individual fields.
	 * 
	 * @return integer container the hash code for this object
	 */
	public int hashCode() {
		return hashCode(letterType) + hashCode(recipientInfo);
	}
}
