package com.demo.insurance.to;

import java.util.List;

/**
 * This class represents a medical report information that is used to score
 * insurance applications and contains a list of medical conditions that the
 * applicant has and a risk rating calculated by the medical agency.
 * 
 * @author Leon Rubin
 */
public class MedicalReport extends ObjectWithReferenceNumber {
	private List<String> medicalConditions;
	private int risk;

	/**
	 * Gets a list of medical conditions. In a real application, each condition
	 * will be represented by a special class, but in this simple demo, a simple
	 * list of strings is sufficient.
	 * 
	 * @return List of medical conditions
	 */
	public List<String> getMedicalConditions() {
		return medicalConditions;
	}

	/**
	 * Sets the medical conditions list.
	 * 
	 * @param medicalConditions
	 *            List of medical conditions
	 */
	public void setMedicalConditions(List<String> medicalConditions) {
		this.medicalConditions = medicalConditions;
	}

	/**
	 * Gets the risk score of the applicant.
	 * 
	 * @return integer containing the risk score of the applican
	 */
	public int getRisk() {
		return risk;
	}

	/**
	 * Sets the risk score of the applicant
	 * 
	 * @param risk
	 *            risk score of the applicant
	 */
	public void setRisk(int risk) {
		this.risk = risk;
	}

	/**
	 * Test the equality of this object and another object by comparing all
	 * individual address fields rather than the default behaviour of comparing
	 * references.
	 * 
	 * @return <code>true</code> if the objects are equal and
	 *         <code>false</code> otherwise
	 */
	public boolean equals(Object o) {
		boolean result = false;

		if (o instanceof MedicalReport) {
			MedicalReport medicalReport = (MedicalReport) o;

			if (medicalConditions.equals(medicalReport.medicalConditions)

			&& risk == medicalReport.risk) {
				result = true;
			}
		}

		return result;
	}

	/**
	 * Creates a hash code for this object by adding the hash codes of
	 * individual fields.
	 * 
	 * @return integer container the hash code for this object
	 */
	public int hashCode() {
		return hashCode(medicalConditions) + hashCode(risk);
	}

	/**
	 * Creates a string representation for this object by printing out the class
	 * name and individual fields to produce a more meaningful output than the
	 * default implementation.
	 * 
	 * @return String representation of this object
	 */
	public String toString() {
		StringBuffer buffer = new StringBuffer();

		buffer.append("\n" + getClass().getName() + "{");
		buffer.append("\n\treferenceNumber=" + getReferenceNumber());
		buffer.append("\n\tmedicalConditions=" + medicalConditions);
		buffer.append("\n\trisk=" + risk);
		buffer.append("\n}\n");

		return buffer.toString();
	}
}
