package com.demo.insurance.to;

/**
 * This class represents a request to the medical report service and contains
 * the information of the person for whom the report should be requested.
 * 
 * @author Leon Rubin
 */
public class MedicalReportRequest extends ObjectWithReferenceNumber {
	private PersonalInfo personalInfo;

	/**
	 * Gets the personal informaiton of the applicant.
	 * 
	 * @return personal informaiton of the applicant
	 */
	public PersonalInfo getPersonalInfo() {
		return personalInfo;
	}

	/**
	 * Sets the personal informaiton of the applicant.
	 * 
	 * @param applicantInfo
	 *            personal informaiton of the applicant
	 */
	public void setPersonalInfo(PersonalInfo personalInfo) {
		this.personalInfo = personalInfo;
	}

	/**
	 * Test the equality of this object and another object by comparing all
	 * individual address fields rather than the default behaviour of comparing
	 * references.
	 * 
	 * @return <code>true</code> if the objects are equal and
	 *         <code>false</code> otherwise
	 */
	public boolean equals(Object o) {
		boolean result = false;

		if (o instanceof MedicalReportRequest) {
			MedicalReportRequest medicalReportRequest = (MedicalReportRequest) o;

			if (personalInfo.equals(medicalReportRequest.personalInfo)
					&& getReferenceNumber().equals(
							medicalReportRequest.getReferenceNumber())) {
				result = true;
			}
		}

		return result;
	}

	/**
	 * Creates a hash code for this object by adding the hash codes of
	 * individual fields.
	 * 
	 * @return integer container the hash code for this object
	 */
	public int hashCode() {
		return hashCode(personalInfo) + hashCode(getReferenceNumber());
	}
}
