package com.demo.insurance.to;

import com.demo.soa.esb.util.to.ModelBean;

/**
 * This class encapsulates personal information of a person (name, SSN, and
 * address).
 * 
 * @author Leon Rubin
 */
public class PersonalInfo extends ModelBean {
	private String firstName;
	private String lastName;
	private String ssn;
	private Address address;

	/**
	 * Gets person's address
	 * 
	 * @return person's address
	 */
	public Address getAddress() {
		return address;
	}

	/**
	 * Sets person's address
	 * 
	 * @param address
	 *            person's address
	 */
	public void setAddress(Address address) {
		this.address = address;
	}

	/**
	 * Gets person's first name
	 * 
	 * @return person's first name
	 */
	public String getFirstName() {
		return firstName;
	}

	/**
	 * Sets person's first name
	 * 
	 * @param firstName
	 *            person's first name
	 */
	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	/**
	 * Gets person's last name
	 * 
	 * @return person's last name
	 */
	public String getLastName() {
		return lastName;
	}

	/**
	 * Sets person's last name
	 * 
	 * @param lastName
	 *            person's last name
	 */
	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	/**
	 * Gets person's Social Security Number
	 * 
	 * @return person's Social Security Number
	 */
	public String getSsn() {
		return ssn;
	}

	/**
	 * Sets person's Social Security Number
	 * 
	 * @param ssn
	 *            person's Social Security Number
	 */
	public void setSsn(String ssn) {
		this.ssn = ssn;
	}

	/**
	 * Test the equality of this object and another object by comparing all
	 * individual address fields rather than the default behaviour of comparing
	 * references.
	 * 
	 * @return <code>true</code> if the objects are equal and
	 *         <code>false</code> otherwise
	 */
	public boolean equals(Object o) {
		boolean result = false;

		if (o instanceof PersonalInfo) {
			PersonalInfo customerInfo = (PersonalInfo) o;

			if (firstName.equals(customerInfo.firstName)
					&& lastName.equals(customerInfo.lastName)
					&& ssn.equals(customerInfo.ssn)
					&& address.equals(customerInfo.address)) {
				result = true;
			}
		}

		return result;
	}

	/**
	 * Creates a hash code for this object by adding the hash codes of
	 * individual fields.
	 * 
	 * @return integer container the hash code for this object
	 */
	public int hashCode() {
		return hashCode(firstName) + hashCode(lastName) + hashCode(ssn)
				+ hashCode(address);
	}

	/**
	 * Creates a string representation for this object by printing out the class
	 * name and individual fields to produce a more meaningful output than the
	 * default implementation.
	 * 
	 * @return String representation of this object
	 */
	public String toString() {
		StringBuffer buffer = new StringBuffer();

		buffer.append("\n\t" + getClass().getName() + "{");
		buffer.append("\n\t\tfirstName=" + firstName);
		buffer.append("\n\t\tlastName=" + lastName);
		buffer.append("\n\t\tssn=" + ssn);
		buffer.append(address);
		buffer.append("\t}\n");

		return buffer.toString();
	}
}
