package com.demo.soa.esb.rulesengine;

import com.demo.soa.esb.rulesengine.drools.RulesEngineDroolsImpl;
import com.demo.soa.esb.util.exception.RulesEngineException;

/**
 * This is a rules engine factory class responsible for creating the instance of
 * the rules engine. This class is the critical part of the factory pattern
 * which allows to create multiple implementations of the engine (Drools
 * implementation, test implementation, etc).
 * 
 * @author Leon Rubin
 */
public class RulesEngineFactory {
	private static RulesEngine rulesEngine;

	/**
	 * Creates and returns an instance of the rules engine. This method is the
	 * only place in the applciation that knows what class is used to implement
	 * the rules engine interface. This method implements a singleton pattern so
	 * the same instance is returned for every call.
	 * 
	 * @return RulesEngine instance
	 */
	public static RulesEngine getRulesEngine() throws RulesEngineException{
		if (rulesEngine == null) {
			rulesEngine = new RulesEngineDroolsImpl();
		}

		return rulesEngine;
	}
}
