package com.demo.soa.esb.rulesengine.drools;

import org.drools.event.ObjectInsertedEvent;
import org.drools.event.ObjectRetractedEvent;
import org.drools.event.ObjectUpdatedEvent;
import org.drools.event.WorkingMemoryEventListener;

import com.demo.soa.esb.rulesengine.drools.dao.WorkingMemoryDAOFactory;
import com.demo.soa.esb.util.exception.DAOException;
import com.demo.soa.esb.util.exception.XMLException;
import com.demo.soa.esb.util.to.ModelBean;
import com.demo.soa.esb.xml.XMLParserFactory;

/**
 * This class implements the <code>WorkingMemoryEventListener</code> interface
 * so an instance can be attached to the Drools working memory to monitor every
 * event related to insertion, updating, or deletion of facts. Every method in
 * this class delegates to the working memory DAO to persist changes in working
 * memory in the database allowing the engine to survive system crashes and
 * restarts.
 * 
 * Javadoc comments for most of the methods are not provided because they will
 * be inherited from the implemented interface during generation.
 * 
 * @author Leon Rubin
 */
public class PersistingWorkingMemoryObserver implements
		WorkingMemoryEventListener {

	public void objectInserted(ObjectInsertedEvent event) {
		try {
			ModelBean object = (ModelBean) event.getObject();
			WorkingMemoryDAOFactory.getDAO().insert(object.getId(),
					XMLParserFactory.getXMLParser().generate(object));
		} catch (XMLException e) {
			e.printStackTrace();
		} catch (DAOException e) {
			e.printStackTrace();
		}
	}

	public void objectRetracted(ObjectRetractedEvent event) {
		try {
			ModelBean object = (ModelBean) event.getOldObject();
			WorkingMemoryDAOFactory.getDAO().remove(object.getId());
		} catch (DAOException e) {
			e.printStackTrace();
		}
	}

	public void objectUpdated(ObjectUpdatedEvent event) {
		try {
			ModelBean object = (ModelBean) event.getObject();
			WorkingMemoryDAOFactory.getDAO().update(object.getId(),
					XMLParserFactory.getXMLParser().generate(object));
		} catch (XMLException e) {
			e.printStackTrace();
		} catch (DAOException e) {
			e.printStackTrace();
		}
	}
}
