package com.demo.soa.esb.rulesengine.drools.dao;

import com.demo.soa.esb.rulesengine.drools.dao.hsql.WorkingMemoryDAOHSQLImpl;
import com.demo.soa.esb.util.exception.DAOException;

/**
 * This is a DAO factory class responsible for creating the instance of the
 * WorkingMemoryDAO. This class is the critical part of the DAO pattern which
 * allows to create multiple implementations of the DAO (JDBC implementation,
 * test implementation, etc).
 * 
 * @author Leon Rubin
 */
public class WorkingMemoryDAOFactory {
	private static WorkingMemoryDAO dao;

	/**
	 * Creates and returns an instance of the working memory DAO. This method is
	 * the only place in the applciation that knows what class is used to
	 * implement the DAO interface. This method implements a singleton patterns
	 * so the same instance is returned for every call.
	 * 
	 * @return WorkingMemoryDAO instance
	 */
	public static WorkingMemoryDAO getDAO() throws DAOException{
		if (dao == null) {
			dao = new WorkingMemoryDAOHSQLImpl();
		}

		return dao;
	}
}
