package com.demo.soa.esb.util.exception;

/**
 * This class represents a data access issue. DAOs will typically receive vendor
 * or framework specific exceptions juch as SQLException while accessing a
 * database with JDBC, but since the purpose of the DAO is to abstract and hide
 * the technology used for data access, all such exceptions should be caught and
 * wrapped as a DAOExceptions.
 * 
 * @author Leon Rubin
 * 
 */
public class DAOException extends Exception {
	private static final long serialVersionUID = 1L;

	/**
	 * Creates a DAO exception with a specified message.
	 * 
	 * @param message
	 *            exception messge
	 */
	public DAOException(String message) {
		super(message);
	}

	/**
	 * Creates a DAO exception with a specified message that wraps another
	 * exception (the root cause of the problem).
	 * 
	 * @param message
	 *            exception messge
	 * @param rootCause
	 *            lower level exception that represents the root cause of the
	 *            problem
	 */
	public DAOException(String message, Throwable rootCause) {
		super(message, rootCause);
	}
}
