package com.demo.soa.esb.util.exception;

/**
 * This class represents a rules engine issue. Rules Engine will typically
 * receive vendor or framework specific exceptions juch as Drools exceptions
 * while evaluating rules, but since the purpose of the factory pattern is to
 * abstract and hide the technology used for data access, all such exceptions
 * should be caught and wrapped as a RulesEngineExceptions.
 * 
 * @author Leon Rubin
 * 
 */
public class RulesEngineException extends Exception {
	private static final long serialVersionUID = 1L;

	/**
	 * Creates a rules engine exception with a specified message.
	 * 
	 * @param message
	 *            exception messge
	 */
	public RulesEngineException(String message) {
		super(message);
	}

	/**
	 * Creates a rules engine exception with a specified message that wraps
	 * another exception (the root cause of the problem).
	 * 
	 * @param message
	 *            exception messge
	 * @param rootCause
	 *            lower level exception that represents the root cause of the
	 *            problem
	 */
	public RulesEngineException(String message, Throwable rootCause) {
		super(message, rootCause);
	}
}
