package com.demo.soa.esb.util.to;

import java.util.Calendar;

/**
 * This abstract class serves as a base for all transfer objects. It declared the
 * id property with corresponding set and get methods and some primitive logic
 * to generate unique IDs.
 * 
 * @author Leon Rubin
 */
public abstract class ModelBean {
	private String id;
	private static int count;

	public ModelBean() {
		id = getClass().getName() + Calendar.getInstance().getTime() + "."
				+ count;
		count++;
	}

	/**
	 * Gets the id of this object.
	 * 
	 * @return String containing the id of this object
	 */
	public String getId() {
		return id;
	}

	/**
	 * Sets the id of this object.
	 * 
	 * @param id
	 *            object id
	 */
	public void setId(String id) {
		this.id = id;
	}

	/**
	 * Gets the hash code of a specified object (if the object reference is
	 * null, returns a 0.
	 * 
	 * @param object
	 *            the object for which the hash code should be obtained
	 * @return integer containing the hash code of a specified object or 0 if
	 *         the object reference is null
	 */
	protected int hashCode(Object object) {
		if (object == null) {
			return 0;
		} else {
			return object.hashCode();
		}
	}
}
