package com.demo.soa.esb.xml;

import com.demo.soa.esb.util.exception.XMLException;
import com.demo.soa.esb.xml.castor.XMLParserCastorImpl;

/**
 * This is an XML parser factory class responsible for creating the instance of
 * the XML parser. This class is the critical part of the factory pattern which
 * allows to create multiple implementations of the parser (Castor
 * implementation, DOM implementation, etc).
 * 
 * @author Leon Rubin
 */
public class XMLParserFactory {
	private static XMLParser xmlParser;

	/**
	 * Creates and returns an instance of the XML parser. This method is the
	 * only place in the applciation that knows what class is used to implement
	 * the XML parser interface. This method implements a singleton pattern so
	 * the same instance is returned for every call.
	 * 
	 * @return XMLParser instance
	 */
	public static XMLParser getXMLParser() throws XMLException {
		if (xmlParser == null) {
			xmlParser = new XMLParserCastorImpl();
		}

		return xmlParser;
	}
}
